@@ -1,6 +1,6 @@
 #include "principal.h"
 #include "aktion_part.h"
-#include <kapp.h>
+#include <kapplication.h>
 #include <kaboutdata.h>
 #include <kcmdlineargs.h>
 #include <klocale.h>
