@@ -8,12 +8,15 @@
 #include <kglobal.h>
 #include <kiconloader.h>
 #include <klocale.h>
-#include <kapp.h>
+#include <kapplication.h>
 #include <kmessagebox.h>
 #include <kfiledialog.h>
-#include <kstddirs.h>
+#include <kstandarddirs.h>
 #include <kseparator.h>
 
+#include <kpopupmenu.h>
+#include <khelpmenu.h>
+
 #include <qtoolbutton.h>
 #include <qiconset.h>
 #include <qlabel.h>
@@ -23,6 +26,7 @@
 #include <qlayout.h>
 #include <qdropsite.h>
 #include <qdragobject.h>
+#include <qcursor.h>
 
 #ifdef XF86_VM
 #include <unistd.h>
@@ -33,6 +37,7 @@
 #include "aktionConf.h"
 
 #include <kwin.h>
+#include <qpopupmenu.h>
 
 Principal::Principal( const char *name)
 	: KMainWindow(0, name, 0)
@@ -128,18 +133,23 @@ Principal::Principal( const char *name)
         retroceder->setAutoRepeat( true );
 	QToolTip::add(retroceder,i18n("Backward"));
 
+	KHelpMenu *mHelpMenu = new KHelpMenu(this, KGlobal::instance()->aboutData(), false);
+
+
 	ayuda = new QToolButton(mainwidget, "ayuda");
 	ayuda->setIconSet(MainBarIconSet("help"));
+	ayuda->setPopup(mHelpMenu->menu());
+	ayuda->setPopupDelay(0);
 	QToolTip::add(ayuda,i18n("Help"));
 
 	configB = new QToolButton(mainwidget, "Setup");
 	configB->setIconSet(MainBarIconSet("configure"));
 	QToolTip::add(configB,i18n("Setup"));
 
+        connect(ayuda,SIGNAL(clicked()),
+		 this,SLOT(open_help()) );
         connect(abrir,SIGNAL(clicked()),
 		 this,SLOT(click_open()) );
-        connect(ayuda,SIGNAL(clicked()),
-		 this,SLOT(click_ayuda()) );
         connect(configB,SIGNAL(clicked()),
 	        this,SLOT(click_config()) );
         connect(tocar,SIGNAL(clicked()),
@@ -230,7 +240,7 @@ void Principal::changeSize(float zoom)
    zH=(float)video->getVideoHeight()*zoom;
    zW=(float)video->getVideoWidth()*zoom;
 
-   resize(zW,zH+volumeSlider->height()+tocar->height()+line->height()+15);
+   resize( (int)zW, (int)zH+volumeSlider->height()+tocar->height()+line->height()+15 );
 }
 
 void Principal::maximize()
@@ -277,6 +287,8 @@ void Principal::waitForKXanimExit()
        but not the cleaner, though.
     */
     tocar->setIconSet(MainBarIconSet("1rightarrow"));
+    QToolTip::remove(tocar);
+    QToolTip::add(tocar, i18n("Play"));
 
     switch (whatToDo)
     {
@@ -304,6 +316,11 @@ bool Principal::queryExit()
            return true;
 }
 
+void Principal::open_help()
+{
+	kapp->invokeHelp();
+}
+
 void Principal::click_open()
 {
     /* the idea behind this method is not very simple:
@@ -324,7 +341,7 @@ void Principal::click_open()
         					     "*.avi *.AVI|AVI files (*.avi)\n"
         					     "*.mov *.MOV|QuickTime files (*.mov)\n"
         					     "*.mpg *.MPG *.mpeg *.MPEG|MPG Files (*.mpg)\n"
-        					     "*.fli *.FLI *.flc *.FLC|FLI/FLC Files (*.fli *.flc)\n"
+        					     "*.fli *.FLI *.flc *.FLC|FLI,FLC Files (*.fli *.flc)\n"
         					     "*|All Files (*)\n")
         				      ,0L,i18n("Select a movie"));
       if (url.isEmpty()) return;
@@ -428,11 +445,6 @@ void Principal::dropEvent( QDropEvent *event )
     }
 }
 
-void Principal::click_ayuda()
-{
-    kapp->invokeHelp();
-}
-
 void Principal::click_play()
 {
     /* maube do we need to resize the whole application? */
@@ -451,10 +463,16 @@ void Principal::click_play()
     isNewVideo=false;
 
     /* set the play button pixmap */
-    if (video->isPlaying()==true)
+    if (video->isPlaying()==true) {
        tocar->setIconSet(MainBarIconSet("1rightarrow"));
+       QToolTip::remove(tocar);
+       QToolTip::add(tocar, i18n("Play"));
+       }
     else
-       tocar->setIconSet(MainBarIconSet("player_pause"));
+       tocar->setIconSet(MainBarIconSet("player_pause")); {
+       QToolTip::remove(tocar);
+       QToolTip::add(tocar, i18n("Pause"));
+       }
 
     // timer->start(100);
     //updateGeometry();
@@ -465,6 +483,8 @@ void Principal::click_forward()
 {
    if (video->isPlaying()==true)
       tocar->setIconSet(MainBarIconSet("1rightarrow"));
+    QToolTip::remove(tocar);
+    QToolTip::add(tocar, i18n("Play"));
    video->stepForward();
 }
 
@@ -472,6 +492,8 @@ void Principal::click_backward()
 {
    if (video->isPlaying()==true)
       tocar->setIconSet(MainBarIconSet("1rightarrow"));
+   QToolTip::remove(tocar);
+   QToolTip::add(tocar, i18n("Play"));
    video->stepBack();
 }
 
@@ -510,6 +532,7 @@ void Principal::setParameters()
     video->setAudio(config->readBoolEntry("enable"));
     video->setAudioSync(config->readBoolEntry("audioSync"));
     video->setInitialVolume(volumeSlider->value());
+    video->setArtsdsp(config->readBoolEntry("useArtsdsp"));
 
     config->setGroup("color");
     video->setColorAhead(config->readNumEntry("colorAhead"));
@@ -578,7 +601,6 @@ void Principal::keyPressEvent( QKeyEvent *key)
                           video->volumeDecrement();
                        }
                        break;
-      case Key_F1    : click_ayuda(); break;
       case Key_Escape: this->close(); break;
       case Key_C     : theCapturer.captureWidget(video); break;
       default        : if (inFullScreen)
@@ -757,8 +779,9 @@ void Principal::goFullScreen()
    {
 #endif
       /* Make the window FULL SCREEN in the traditional way */
-      sizeW = QApplication::desktop()->width();
-      sizeH = QApplication::desktop()->height();
+      int scnum = QApplication::desktop()->screenNumber(this);
+      sizeW = QApplication::desktop()->screenGeometry(scnum).width();
+      sizeH = QApplication::desktop()->screenGeometry(scnum).height();
 #ifdef XF86_VM
    }
 #endif
