@@ -20,24 +20,23 @@
     */
 
 #include "namedlg.h"
-#include "portablekde.h"
 
 #include <qlayout.h>
 #include <qlabel.h>
-#include <qbttngrp.h>
-#include <qradiobt.h>
-#include <qlined.h>
+#include <qbuttongroup.h>
+#include <qradiobutton.h>
+#include <qlineedit.h>
 #include <kseparator.h>
 #include <kbuttonbox.h>
-#include <kapp.h>
+#include <klocale.h>
+#include <kapplication.h>
+#include <qpushbutton.h>
 
-#ifndef KDE_USE_FINAL
 static void min_size(QWidget *w) {
   w->setMinimumSize(w->sizeHint());
 } 
-#endif
 
-NameDlg::NameDlg(QWidget *parent, const char *oldname, const char *title) :QDialog(parent,title, TRUE)
+NameDlg::NameDlg(QWidget *parent, const QString &oldname, const QString &title) :QDialog(parent, "", TRUE)
 {
 	QVBoxLayout *mainlayout = new QVBoxLayout(this);
 
@@ -100,7 +99,7 @@ NameDlg::NameDlg(QWidget *parent, const char *oldname, const char *title) :QDial
 	mainlayout->freeze();
 };
 
-const char *NameDlg::name()
+QString NameDlg::name()
 {
 	return edit->text();
 }
