@@ -23,7 +23,6 @@
 #define __RETRIEVEDLG_H_
 
 #include "structure.h"
-#include "portablekde.h"
 
 #include <qdialog.h>
 #include <qtimer.h>
@@ -39,7 +38,6 @@ class RetrieveDlg :public QDialog {
 	QListBox *listbox;
 public:
 	RetrieveDlg(QWidget *parent);
-public slots:
-	const char *result();
+	QString result();
 };
 #endif
