@@ -76,11 +76,13 @@ public:
 
 	TimeStamp time()
 	{
-		timeval tv;
-		gettimeofday(&tv, 0);
-		return TimeStamp(tv.tv_sec, tv.tv_usec);
+		return timer.time();
 	}
 
+	TimeStamp playTime()
+	{
+		return timer.time();
+	}
 };
 
 REGISTER_IMPLEMENTATION(Synth_MIDI_DEBUG_impl);
