@@ -1,3 +1,25 @@
+    /*
+
+    Copyright (C) 2000,2001 Stefan Westerfeld
+                            stefan@space.twc.de
+
+    This library is free software; you can redistribute it and/or
+    modify it under the terms of the GNU Library General Public
+    License as published by the Free Software Foundation; either
+    version 2 of the License, or (at your option) any later version.
+  
+    This library is distributed in the hope that it will be useful,
+    but WITHOUT ANY WARRANTY; without even the implied warranty of
+    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+    Library General Public License for more details.
+   
+    You should have received a copy of the GNU Library General Public License
+    along with this library; see the file COPYING.LIB.  If not, write to
+    the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
+    Boston, MA 02111-1307, USA.
+
+    */
+
 #include "artsbuilder.h"
 #include "artsflow.h"
 #include "connect.h"
@@ -5,9 +27,11 @@
 #include "flowsystem.h"
 #include "stdsynthmodule.h"
 #include "dynamicrequest.h"
+#include "dynamicskeleton.h"
+#include "startupmanager.h"
 #include <list>
 
-#undef STRUCTURE_DEBUG
+//#define STRUCTBUILDER_DEBUG 1
 
 using namespace Arts;
 using namespace std;
@@ -18,19 +42,32 @@ protected:
 public:
 	void addFactory(ObjectFactory factory);
 	Object createObject(StructureDesc structure);
+	ModuleDef createTypeInfo(StructureDesc structure);
 };
 
 REGISTER_IMPLEMENTATION(StructureBuilder_impl);
 
-class Structure_impl : virtual public SynthModule_skel,
+typedef DynamicSkeleton<SynthModule_skel> SynthModule_dskel;
+
+class Structure_impl : virtual public SynthModule_dskel,
                        virtual public StdSynthModule {
 protected:
 	list<Object> structureObjects;
 
+	struct ForwardMethod {
+		string method;
+		Object destObject;
+		string destMethod;
+	};
+
+	list<ForwardMethod> forwardMethods;
+
 public:
 	Structure_impl(StructureDesc structure, list<ObjectFactory>& factories);
 	void streamInit();
 	void streamEnd();
+
+	void process(long methodID, Buffer *request, Buffer *result);
 };
 
 void StructureBuilder_impl::addFactory(ObjectFactory factory)
@@ -38,13 +75,82 @@ void StructureBuilder_impl::addFactory(ObjectFactory factory)
 	factories.push_back(factory);
 }
 
+ModuleDef StructureBuilder_impl::createTypeInfo(StructureDesc structure)
+{
+	ModuleDef md;
+	InterfaceDef id;
+
+/* convert structure to InterfaceDef id */
+	md.moduleName = id.name = structure.name();
+	id.inheritedInterfaces.push_back("Arts::SynthModule");
+
+	vector<string> *otherInterfaces = structure.inheritedInterfaces();
+	vector<string>::iterator ii;
+	for(ii = otherInterfaces->begin(); ii != otherInterfaces->end(); ii++)
+		id.inheritedInterfaces.push_back(*ii);
+	delete otherInterfaces;
+
+	vector<StructurePortDesc> *ports = structure.ports();
+	vector<StructurePortDesc>::iterator pi;
+	for(pi = ports->begin(); pi != ports->end(); pi++)
+	{
+		const Arts::PortType& type = pi->type();
+
+		// if we inherited the port from a parent interface, we don't need to
+		// list it in our interface description
+		if(pi->inheritedInterface() == "")
+		{
+			AttributeDef ad;
+			ad.name = pi->name();
+
+			// This is a little tricky, as input ports (which are bringing data
+			// from outside into the structure) are saved as output ports (and
+			// output ports as input ports).
+			ad.flags = AttributeType(
+					((type.direction == input)?streamOut:streamIn) |
+					((type.connType == conn_stream)?attributeStream:attributeAttribute)
+					);
+			ad.type = type.dataType;
+
+			id.attributes.push_back(ad);
+		}
+	}
+	delete ports;
+
+	md.interfaces.push_back(id);
+
+	return md;
+}
+
+namespace Arts {
+static class StructureBuilderCleanUp : public StartupClass {
+public:
+	vector<long> types;
+	void startup() { };
+	void shutdown() {
+		vector<long>::iterator i;
+		for(i = types.begin(); i != types.end(); i++)
+			Dispatcher::the()->interfaceRepo().removeModule(*i);
+		types.clear();
+	}
+	virtual ~StructureBuilderCleanUp() {}
+} structureBuilderCleanUp;
+};
+
 Object StructureBuilder_impl::createObject(StructureDesc structure)
 {
-	return Object::_from_base(new Structure_impl(structure, factories));
+	ModuleDef md = createTypeInfo(structure);
+
+	// FIXME: find some faster way of ensuring type consistency than creating
+	// the thing from scratch every time
+	structureBuilderCleanUp.types.push_back(Dispatcher::the()->interfaceRepo().insertModule(md));
+	Object obj = Object::_from_base(new Structure_impl(structure, factories));
+	return obj;
 }
 
 Structure_impl::Structure_impl(StructureDesc structureDesc,
 									list<ObjectFactory>& factories)
+	: SynthModule_dskel(structureDesc.name())
 {
 	map<long, Object> moduleMap;
 	vector<ModuleDesc> *modules = structureDesc.modules();
@@ -152,33 +258,6 @@ Structure_impl::Structure_impl(StructureDesc structureDesc,
 
 	vector<StructurePortDesc> *ports = structureDesc.ports();
 	vector<StructurePortDesc>::iterator pi;
-	for(pi = ports->begin(); pi != ports->end(); pi++)
-	{
-		const Arts::PortType& type = pi->type();
-
-		// This is a little tricky, as input ports (which are bringing data
-		// from outside into the structure) are saved as output ports (and
-		// output ports as input ports).
-
-		if(type.direction == input && type.dataType == "float" &&
-		   type.connType == conn_stream)
-		{
-			float **f = new (float *);
-			_initStream(pi->name(),f,streamOut | attributeStream);
-#ifdef STRUCTBUILDER_DEBUG
-			cout << "structure: outport " << pi->name() << " created";
-#endif
-		}
-		if(type.direction == output && type.dataType == "float" &&
-		   type.connType == conn_stream)
-		{
-			float **f = new (float *);
-			_initStream(pi->name(),f,streamIn | attributeStream);
-#ifdef STRUCTBUILDER_DEBUG
-			cout << "inport " << pi->name() << " created";
-#endif
-		}
-	}
 
 	for(pi = ports->begin(); pi != ports->end(); pi++)
 	{
@@ -200,6 +279,15 @@ Structure_impl::Structure_impl(StructureDesc structureDesc,
 #endif
 
 				_node()->virtualize(pd.name(),dest._node(),ci->name());
+
+				if(pd.type().connType == conn_property)
+				{
+					ForwardMethod fm;
+					fm.method = "_set_"+pd.name();
+					fm.destObject = dest;
+					fm.destMethod = "_set_"+ci->name();
+					forwardMethods.push_back(fm);
+				}
 			}
 			delete connections;
 		}
@@ -234,3 +322,26 @@ void Structure_impl::streamEnd()
 		if(i->_base()->_isCompatibleWith("Arts::SynthModule"))
 			i->_node()->stop();
 }
+
+void Structure_impl::process(long methodID, Buffer *request, Buffer *result)
+{
+	const MethodDef& methodDef = getMethodDef(methodID);
+
+	arts_debug("Structure_impl: got method, method ID=%ld name='%s'",
+				methodID, methodDef.name.c_str());
+
+	list<ForwardMethod>::iterator fi;
+	for(fi = forwardMethods.begin(); fi != forwardMethods.end(); fi++)
+	{
+		if(fi->method == methodDef.name)
+		{
+			Any a;
+			a.type = methodDef.signature[0].type;
+
+			while(request->remaining() > 0)
+				a.value.push_back(request->readByte());
+
+			DynamicRequest(fi->destObject).method(fi->destMethod).param(a).invoke();
+		}
+	}
+}
