@@ -1,7 +1,7 @@
 #include <qlayout.h>
 #include <qpainter.h>
 #include <qfontmetrics.h>
-#include <qlist.h>
+#include <qptrlist.h>
 #include <kled.h>
 #include "levelmeters.h"
 
@@ -41,7 +41,7 @@ void PeakBar::checkMinMax() {
 		maxValue= 0.f;
 		minValue= 1.f;
 		clipped = false;
-		for (QListIterator<Observation> it(lastValues); it.current(); ++it) {
+		for (QPtrListIterator<Observation> it(lastValues); it.current(); ++it) {
 			float value= it.current()->value;
 			if (value>maxValue)
 				maxValue= value;
