@@ -20,6 +20,7 @@
     */
 
 #include "main.h"
+#include "environmentview.h"
 #include "main.moc"
 #include "levelmeters.h"
 #include "objectmanager.h"
@@ -36,6 +37,7 @@
 #include <klistview.h>
 #include <kdebug.h>
 #include <audiomanager.h>
+#include <kartsserver.h>
 #include <iostream>
 #include <map>
 
@@ -255,7 +257,8 @@ void ArtsStatusView::closeEvent(QCloseEvent *e)
 
 VControl::VControl(QWidget *parent) : QFrame(parent), scopeView(0), mediaView(0),
 	freeVerbView(0), audioManager(0), artsStatusView(0), midiManagerView(0),
-	server(Reference("global:Arts_SoundServerV2")), inUpdate(false)
+	server(KArtsServer().server()), environmentView(0),
+	inUpdate(false)
 {
    	if(server.isNull())
    	{
@@ -304,6 +307,7 @@ VControl::~VControl()
 	removeMediaView();
 	removeArtsStatusView();
 	removeMidiManager();
+	removeEnvironment();
 }
 
 void VControl::updateScales()
@@ -363,6 +367,15 @@ void VControl::showFreeVerbView()
 	}
 }
 
+void VControl::showEnvironment()
+{
+	if(!environmentView)
+	{
+		environmentView = new EnvironmentView(defaultEnvironment());
+		connect(environmentView,SIGNAL(closed()),this,SLOT(removeEnvironment()));
+	}
+}
+
 void VControl::showAudioManager()
 {
 	if(!audioManager)
@@ -412,6 +425,13 @@ void VControl::removeMidiManager()
 	midiManagerView = 0;
 }
 
+void VControl::removeEnvironment()
+{
+	if(environmentView) delete environmentView;
+	environmentView = 0;
+}
+
+
 void VControl::removeScopeView()
 {
 	if(scopeView) delete scopeView;
@@ -453,6 +473,8 @@ MainWindow::MainWindow() : KMainWindow(0)
 		SLOT(showArtsStatusView()), actionCollection(), "view_arts_statusview");
 	(void)new KAction(i18n("View &Midi Manager"), 0, vc,
 		SLOT(showMidiManager()), actionCollection(), "view_midi_manager");
+	(void)new KAction(i18n("View &Environment"), 0, vc,
+		SLOT(showEnvironment()), actionCollection(), "view_environment");
 	(void)new KAction(i18n("View Available Media &Types"), 0, vc,
 		SLOT(showMediaView()), actionCollection(), "view_media_types");
 	(void)new KAction(i18n("Free&Verb"), 0, vc,
