@@ -21,7 +21,7 @@
 
 #include "midiinstdlg.h"
 #include <klocale.h>
-#include <kstddirs.h>
+#include <kstandarddirs.h>
 
 #include <qlayout.h>
 #include <qlabel.h>
@@ -30,6 +30,8 @@
 #include <kbuttonbox.h>
 #include <kseparator.h>
 #include <kdebug.h>
+#include <qbutton.h>
+#include <qpushbutton.h>
 
 static QStringList getArtsPath()
 {
