@@ -30,6 +30,7 @@
 #include <qpushbutton.h>
 #include <qlistbox.h>
 #include <qlayout.h>
+#include <qpainter.h>
 #include <stdio.h>
 #include <kaction.h>
 #include <klocale.h>
@@ -42,6 +43,22 @@
 using namespace Arts;
 using namespace std;
 
+/* quick hack as long as the sound server doesn't support environments */
+Arts::Environment::Container defaultEnvironment()
+{
+	Arts::SimpleSoundServer server = Reference("global:Arts_SimpleSoundServer");
+	Arts::Environment::Container d = 
+		Arts::DynamicCast(server._getChild("defaultEnvironment"));
+
+	if(d.isNull())
+	{
+		d = Arts::DynamicCast(
+			server.createObject("Arts::Environment::Container"));
+		server._addChild(d,"defaultEnvironment");
+	}
+	return d;
+}
+
 class MidiManagerItem : public QListBoxText {
 public:
 	MidiClientInfo info;
@@ -219,11 +236,17 @@ void MidiManagerView::addArtsMidiOutput()
 		SoundServer s = Reference("global:Arts_SoundServer");
 		if(!s.isNull())
 		{
+		/*
 			Synth_MIDI_TEST t
 				= DynamicCast(s.createObject("Arts::Synth_MIDI_TEST"));
 			t.filename(dlg->filename().data());
 			t.start();
 			t._addChild(t,"avoid_delete");
+			*/
+			Environment::InstrumentItem item = DynamicCast(
+				defaultEnvironment().createItem("Arts::Environment::InstrumentItem"));
+			if(!item.isNull())
+				item.filename(dlg->filename().data());
 		}
 	}
 }
