@@ -24,14 +24,13 @@
 
 #include <qlayout.h>
 #include <qlabel.h>
-#include <qframe.h>
+#include <kseparator.h>
 #include <kbuttonbox.h>
-#include <qbttngrp.h>
-#include <qradiobt.h>
-#include <qlined.h>
-#include <kapp.h>
+#include <qlineedit.h>
+#include <qbutton.h>
+#include <qpushbutton.h>
 
-MidiPortDlg::MidiPortDlg(QWidget *parent, const char *oldname, const char *title) :QDialog(parent,title, TRUE)
+MidiPortDlg::MidiPortDlg(QWidget *parent, const char *oldname, const char *title) :QDialog(parent,title,TRUE)
 {
 	QVBoxLayout *mainlayout = new QVBoxLayout(this);
 
@@ -42,7 +41,7 @@ MidiPortDlg::MidiPortDlg(QWidget *parent, const char *oldname, const char *title
 	QFont labelfont(captionlabel->font());
 	labelfont.setPointSize(labelfont.pointSize()*3/2);
 	captionlabel->setFont(labelfont);
-	captionlabel->setText(QString(" ")+QString(title)+QString(" "));
+	captionlabel->setText(i18n("OSS Midi Port"));
 	captionlabel->setAlignment(AlignCenter);
 	//min_size(captionlabel);
 	mainlayout->addWidget(captionlabel);
@@ -50,11 +49,8 @@ MidiPortDlg::MidiPortDlg(QWidget *parent, const char *oldname, const char *title
 // hruler
 
 	mainlayout->addSpacing(5);
-	QFrame *ruler2 = new QFrame(this);
-	ruler2->setFrameStyle(QFrame::HLine | QFrame::Sunken);
-	ruler2->setMinimumSize(50,2);
+	KSeparator *ruler2 = new KSeparator( KSeparator::HLine, this);
 	mainlayout->addWidget(ruler2);
-
 	mainlayout->addSpacing(5);
 
 // editwidget
@@ -68,11 +64,8 @@ MidiPortDlg::MidiPortDlg(QWidget *parent, const char *oldname, const char *title
 // hruler
 
 	mainlayout->addSpacing(5);
-	QFrame *ruler = new QFrame(this);
-	ruler->setFrameStyle(QFrame::HLine | QFrame::Sunken);
-	ruler->setMinimumSize(50,2);
+	KSeparator *ruler = new KSeparator( KSeparator::HLine, this);
 	mainlayout->addWidget(ruler);
-
 	mainlayout->addSpacing(5);
 
 // buttons
@@ -103,3 +96,4 @@ const char *MidiPortDlg::device()
 {
 	return edit->text().ascii();
 }
+#include "midiportdlg.moc"
