@@ -17,7 +17,7 @@
     along with this program; if not, write to the Free Software
     Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 
-    Send comments and bug fixes to antlarr@arrakis.es
+    Send comments and bug fixes to larrosa@kde.org
     or to Antonio Larrosa, Rio Arnoya, 10 5B, 29006 Malaga, Spain
 
 ***************************************************************************/
@@ -33,6 +33,7 @@
 
 
 #define NUMPREVLINES 2
+//#define DRAW_BOUNDING_RECTS
 
 
 KDisplayText::KDisplayText(QWidget *parent,const char *name) : QScrollView(parent,name)
@@ -65,11 +66,12 @@ KDisplayText::~KDisplayText()
   RemoveLinkedList();
 }
 
-void KDisplayText::PreDestroyer(void)
+/*void KDisplayText::PreDestroyer(void)
 {
   delete qfmetr;
   delete qtextfont;
 }
+*/
 
 void KDisplayText::RemoveLine(kdispt_line *tmpl)
 {
@@ -79,7 +81,7 @@ void KDisplayText::RemoveLine(kdispt_line *tmpl)
     tmpe=tmpl->ev;
     tmpl->ev=tmpe->next;
     //    delete tmpe->spev; Remember that the Special Events that this pointer
-    //		 pointers to is the same that the Player object has instantiated
+    //		 points to is the same that the Player object has instantiated
     delete tmpe;
   }
 }
@@ -185,10 +187,12 @@ void KDisplayText::calculatePositions(void)
     int tmpw=0;
     int maxx=0;
     nlines=nlines_[(typeoftextevents==1)? 0:1];
+    int lineSpacing=qfmetr->lineSpacing();
+    int descent=qfmetr->descent();
     while (!fin)
     {
         tmpl=linked_list_[(typeoftextevents==1)?0:1];
-        tmpy=qfmetr->lineSpacing();
+        tmpy=lineSpacing;
         maxx=0;
         while (tmpl!=NULL)
         {
@@ -200,7 +204,7 @@ void KDisplayText::calculatePositions(void)
                 {
                     if (IsLineFeed(tmp->spev->text[0],typeoftextevents))
                     {
-                        tmpy+=qfmetr->lineSpacing();
+                        tmpy+=lineSpacing;
                         tmpx=5;
 
                         tmp->xpos=tmpx;
@@ -214,19 +218,23 @@ void KDisplayText::calculatePositions(void)
                         tmpw=qfmetr->width(tmp->spev->text);
                         tmp->r=qfmetr->boundingRect(tmp->spev->text);
                     }
-                    tmp->r.moveBy(tmpx,tmpy);
+	// We add 5 pixels above, below and to the right because of a
+	// problem with latest released Xft
+                    tmp->r.moveBy(tmpx,tmpy-tmp->r.height()-tmp->r.y()-5);
+		    tmp->r.setHeight(tmp->r.height()+descent+10);
+		    tmp->r.setWidth(tmp->r.width()+5);
                     tmpx+=tmpw;
 		    if (tmpx>maxx) maxx=tmpx;
                 }
                 tmp=tmp->next;
             }
-            tmpl->ypos=tmpl->num*qfmetr->lineSpacing();
+            tmpl->ypos=tmpl->num*lineSpacing;
             tmpy=tmpl->ypos;
             tmpl=tmpl->next;
         }
         maxX[(typeoftextevents==1)?0:1]=maxx+10;
-        maxY[(typeoftextevents==1)?0:1]=nlines_[(typeoftextevents==1)?0:1]*qfmetr->lineSpacing()+
-				qfmetr->descent()+10;
+        maxY[(typeoftextevents==1)?0:1]=
+		nlines_[(typeoftextevents==1)?0:1]*lineSpacing+descent+10;
  
         if (typeoftextevents==1) typeoftextevents=5;
         else fin=1;
@@ -239,7 +247,8 @@ kdispt_line *KDisplayText::searchYOffset(int y, kdispt_line *start)
 kdispt_line *t=start;
 while (t!=NULL)
    {
-   if (t->ypos+qfmetr->descent()>y) return start;
+//   if (t->ypos+qfmetr->descent()>y) return start;
+   if (t->ypos+qfmetr->descent()+20>y) return start;
    start=t;
    t=t->next;
    };
@@ -289,6 +298,12 @@ void KDisplayText::drawContents(QPainter *p,int clipx,int clipy,int clipw,int cl
                 p->drawText(tmp->xpos,tmpl->ypos,&tmp->spev->text[1]);
             else
                 p->drawText(tmp->xpos,tmpl->ypos,tmp->spev->text);
+
+#ifdef DRAW_BOUNDING_RECTS
+	    p->setPen(red);
+	    p->drawRect(tmp->r);
+ 	    p->setPen((colorplayed)?yellow:black);
+#endif
             tmp=tmp->next;
             while ((tmp!=NULL)&&(tmp->spev->type!=typeoftextevents)) tmp=tmp->next;
         }
@@ -351,6 +366,7 @@ void KDisplayText::CursorToHome(void)
 
 void KDisplayText::PaintIn(int type)
 {
+  bool paint=false;
   if (type!=typeoftextevents)
   {
     int idx=(type==1)?0:1;
@@ -376,14 +392,14 @@ void KDisplayText::PaintIn(int type)
     return;
   }
 
+  kdispt_ev *tmp=cursor;
   if (cursor->spev->type==typeoftextevents)
   {
 //    int x,y;
 //    contentsToViewport(cursor->xpos,cursor_line->ypos,x,y);
 
-    kdispt_ev *tmp=cursor;
     cursor=cursor->next;
-    if (tmp!=NULL) repaintContents(tmp->r);
+    paint=true;
 
   }
   else 
@@ -410,6 +426,7 @@ void KDisplayText::PaintIn(int type)
 //	scrollBy(0,qfmetr->lineSpacing());
     }
   }
+  if (paint) repaintContents(tmp->r);
 }
 
 void KDisplayText::gotomsec(ulong i)
@@ -601,3 +618,4 @@ void KDisplayText::timerEvent(QTimerEvent *e)
 {
 return QSize(400,200);
 }*/
+#include "kdisptext.moc"
