@@ -47,11 +47,11 @@ KMidFactory::~KMidFactory()
   s_instance = 0;
 }
 
-QObject *KMidFactory::create(QObject *parent, const char *name, const char*,
+KParts::Part *KMidFactory::createPartObject(QWidget *parentWidget, const char *widgetName,
+                                            QObject *parent, const char *name, const char*,
     const QStringList& )
 {
-  QObject *obj = new KMidPart((QWidget*)parent, name);
-  emit objectCreated(obj);
+  KParts::Part *obj = new KMidPart(parentWidget, widgetName, parent, name);
   return obj;
 }
 
@@ -75,12 +75,13 @@ KInstance *KMidFactory::instance()
   return s_instance;
 }
 
-  KMidPart::KMidPart(QWidget *parent, const char *name)
+  KMidPart::KMidPart(QWidget *parentWidget, const char *widgetName,
+                     QObject *parent, const char *name)
 : KParts::ReadOnlyPart(parent, name)
 {
   setInstance(KMidFactory::instance());
 
-  widget = new kmidClient(parent, actionCollection());
+  widget = new kmidClient(parentWidget, actionCollection());
   widget->show();
   widget->setFocusPolicy(QWidget::ClickFocus);
   setWidget(widget);
