@@ -17,7 +17,7 @@
     along with this program; if not, write to the Free Software
     Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 
-    Send comments and bug fixes to antlarr@arrakis.es
+    Send comments and bug fixes to larrosa@kde.org
     or to Antonio Larrosa, Rio Arnoya, 10 5B, 29006 Malaga, Spain
 
 ***************************************************************************/
@@ -33,7 +33,7 @@
 #include <qstring.h>
 
 #include <kaccel.h>
-#include <kapp.h>
+#include <kapplication.h>
 #include <kconfig.h>
 #include <kfiledialog.h>
 #include <kfontdialog.h>
@@ -116,10 +116,10 @@ kmidFrame::kmidFrame(const char *name)
 		actionCollection(), "collect_organize");  
 
     QStringList playmodes;
-    playmodes.append(i18n("In order"));
+    playmodes.append(i18n("In Order"));
     playmodes.append(i18n("Shuffle"));
 
-    KSelectAction *act=new KSelectAction(i18n("Play order"), 0, /*this, SLOT(collect_PlayOrder(int)),*/
+    KSelectAction *act=new KSelectAction(i18n("Play Order"), 0, /*this, SLOT(collect_PlayOrder(int)),*/
                       actionCollection(), "play_order");
     connect(act,SIGNAL(activated(int)),this, SLOT(collect_PlayOrder(int)));
     act->setItems(playmodes);  
@@ -131,51 +131,51 @@ kmidFrame::kmidFrame(const char *name)
     playmodes.append(i18n("&General Midi"));
     playmodes.append(i18n("&MT-32"));
     
-    act=new KSelectAction(i18n("File type"), 0,/* this, SLOT(options_FileType(int)),*/
+    act=new KSelectAction(i18n("File Type"), 0,/* this, SLOT(options_FileType(int)),*/
                       actionCollection(), "file_type");
     connect(act,SIGNAL(activated(int)),this, SLOT(options_FileType(int)));
-    act->setItems(playmodes);  
+    act->setItems(playmodes);
 
     playmodes.clear();
-    playmodes.append(i18n("&Text events"));
-    playmodes.append(i18n("&Lyric events"));
+    playmodes.append(i18n("&Text Events"));
+    playmodes.append(i18n("&Lyric Events"));
 
-    act=new KSelectAction(i18n("Display events"), Key_T, /*this, 
+    act=new KSelectAction(i18n("Display Events"), Key_T, /*this,
 		SLOT(options_DisplayEvents(int)),*/ actionCollection(), 
 		"display_events");
     connect(act,SIGNAL(activated(int)),this, SLOT(options_DisplayEvents(int)));
     act->setItems(playmodes);  
 
-    (void)new KToggleAction(i18n("Automatic text chooser"), 0, this, 
-		SLOT(options_AutomaticText()), actionCollection(), 
-		"option_automatictext");  
-    
-    (void)new KToggleAction(i18n("Show &Volume Bar"), "volume", 
+    (void)new KToggleAction(i18n("Automatic Text Chooser"), 0, this, 
+		SLOT(options_AutomaticText()), actionCollection(),
+		"option_automatictext");
+
+    (void)new KToggleAction(i18n("Show &Volume Bar"), "volume",
 		0, this, SLOT(options_ShowVolumeBar()), actionCollection(),
-		"toggle_volumebar");  
-    
-    (void)new KToggleAction(i18n("Show &Channel View"), "piano", 
-		0, this, SLOT(options_ShowChannelView()), actionCollection(), 
-		"toggle_channelview");  
-    
-    (void)new KAction(i18n("Channel View &Options ..."), 0, this, 
-		SLOT(options_ChannelViewOptions()), actionCollection(), 
-		"channelview_options");  
-    
-    (void)new KAction(i18n("&Font Change ..."), 0, this, 
-		SLOT(options_FontChange()), actionCollection(), 
-		"change_font");  
+		"toggle_volumebar");
 
-    (void)new KAction(i18n("Configure &Keys ..."), 0, this, 
-		SLOT(options_KeyConfig()), actionCollection(), 
-		"configure_keys");  
+    (void)new KToggleAction(i18n("Show &Channel View"), "piano",
+		0, this, SLOT(options_ShowChannelView()), actionCollection(),
+		"toggle_channelview");
 
-    (void)new KAction(i18n("Midi &Setup ..."), 0, this, 
-		SLOT(options_MidiSetup()), actionCollection(), "midi_setup");  
+    (void)new KAction(i18n("Channel View &Options ..."), 0, this,
+		SLOT(options_ChannelViewOptions()), actionCollection(),
+		"channelview_options");
+
+    (void)new KAction(i18n("&Font Change ..."), 0, this,
+		SLOT(options_FontChange()), actionCollection(),
+		"change_font");
+
+    (void)new KAction(i18n("Configure &Keys ..."), 0, this,
+		SLOT(options_KeyConfig()), actionCollection(),
+		"configure_keys");
+
+    (void)new KAction(i18n("Midi &Setup ..."), 0, this,
+		SLOT(options_MidiSetup()), actionCollection(), "midi_setup");
 
 
     createGUI( "kmidui.rc" );
-    
+
     KConfig *cfg=kapp->config();
     cfg->setGroup("KMid");
     KSelectAction *tmplistaction=
@@ -269,7 +269,6 @@ kmidFrame::kmidFrame(const char *name)
 
 kmidFrame::~kmidFrame()
 {
-    delete kmidclient;
 }
 
 void kmidFrame::file_Open()
@@ -281,7 +280,7 @@ void kmidFrame::file_Open()
       
   if( !url.isLocalFile() )
   {
-    KMessageBox::sorry( 0L, i18n( "Only local files are supported yet." ) );
+    KMessageBox::sorry( 0L, i18n( "Only local files are currently supported." ) );
     return;
   }
       
@@ -409,6 +408,7 @@ void kmidFrame::shuttingDown()
 //      kmidclient->stop();
       kmidclient->shuttingDown();
    }
+   kmidclient->saveCollections();
 }
 
 void kmidFrame::saveProperties(KConfig *cfg)
@@ -448,7 +448,7 @@ void kmidFrame::options_MidiSetup()
   if (kmidclient->devman()->checkInit()<0) 
   {
     KMessageBox::error(this,
-	i18n("Couldn't open /dev/sequencer to get some info\nProbably there is another program using it"));
+	i18n("Couldn't open /dev/sequencer to get some info.\nProbably there is another program using it."));
     return;
   }
   MidiConfigDialog *dlg;
@@ -533,14 +533,14 @@ void kmidFrame::collect_AutoAdd()
 
 void kmidFrame::file_SaveLyrics()
 {
-  KURL url = KFileDialog::getSaveURL(QString::null,"*.*",this);
-    
+  KURL url = KFileDialog::getSaveURL(QString::null,"*",this);
+
   if( url.isEmpty() )
     return;
 
   if( !url.isLocalFile() )
   {
-    KMessageBox::sorry( 0L, i18n( "Only local files supported yet." ) );
+    KMessageBox::sorry( 0L, i18n( "Only local files are currently supported." ) );
     return;
   }
 
@@ -722,3 +722,4 @@ void kmidFrame::setMidiDevice(int i)
 */
 
 
+#include "kmidframe.moc"
