@@ -23,11 +23,12 @@
     Note: This widget was based on KButton as found in the kdelibs/kdeui
     KButton was originally copyrighted by Torben Weis (weis@kde.org)
     and Matthias Ettrich (ettrich@kde.org) on 1997
-     
+
 ***************************************************************************/
 #include "ktrianglebutton.h"
 #include <qpainter.h>
 #include <qdrawutil.h>
+#include <qstyle.h>
 
 KTriangleButton::KTriangleButton( Direction d,QWidget *_parent, const char *name )
     : QButton( _parent , name)
@@ -58,7 +59,7 @@ void KTriangleButton::leaveEvent( QEvent * )
       repaint();
     }
 }
-    
+
 
 void KTriangleButton::drawButton( QPainter *_painter )
 {
@@ -74,23 +75,23 @@ void KTriangleButton::paint( QPainter *painter )
 {
   if ( isDown() || isOn() )
     {
-      if ( style().guiStyle() == WindowsStyle )
-	qDrawWinButton( painter, 0, 0, width(), 
+      if ( style().styleHint(QStyle::SH_GUIStyle) == WindowsStyle )
+	qDrawWinButton( painter, 0, 0, width(),
 			height(), colorGroup(), TRUE );
       else
-	qDrawShadePanel( painter, 0, 0, width(), 
+	qDrawShadePanel( painter, 0, 0, width(),
 			 height(), colorGroup(), TRUE, 2, 0L );
     }
   else if ( raised )
     {
-      if ( style().guiStyle() == WindowsStyle )
-	qDrawWinButton( painter, 0, 0, width(), height(), 
+      if ( style().styleHint(QStyle::SH_GUIStyle) == WindowsStyle )
+	qDrawWinButton( painter, 0, 0, width(), height(),
 			colorGroup(), FALSE );
       else
-	qDrawShadePanel( painter, 0, 0, width(), height(), 
+	qDrawShadePanel( painter, 0, 0, width(), height(),
 			 colorGroup(), FALSE, 2, 0L );
     }
-  
+
   if (dir==Right)
   {
       int x=width()/4;
@@ -121,9 +122,9 @@ void KTriangleButton::paint( QPainter *painter )
           x--;
           i++;
       };
- 
+
   };
-  
+
 }
 
 void KTriangleButton::mousePressEvent(QMouseEvent *e)
@@ -158,6 +159,6 @@ void KTriangleButton::timerEvent(QTimerEvent *)
         }
     else if (timeCount>0) timeCount++;
     emit clickedQuickly();
-    
+
 }
 #include "ktrianglebutton.moc"
