@@ -1,5 +1,5 @@
 /*
-	$Id: config.h,v 1.51 2001/06/06 18:56:02 mueller Exp $
+	$Id: config.h,v 1.52 2001/10/21 03:07:30 waba Exp $
 
     TiMidity -- Experimental MIDI to WAVE converter
     Copyright (C) 1995 Tuukka Toivonen <toivonen@clinet.fi>
@@ -269,7 +269,7 @@ typedef char int8;
 	#endif
 #else
 	#define XCHG_SHORT(x) ((((x)&0xFF)<<8) | (((x)>>8)&0xFF))
-	#ifdef __i486__
+	#if defined(__i486__) && defined(__GNUC__)
 		#define XCHG_LONG(x) \
 			({ int32 __value; \
 			asm ("bswap %1; movl %1,%0" : "=g" (__value) : "r" (x)); \
