@@ -2,7 +2,7 @@
 
    kmidi - a midi to wav converter
 
-   $Id: kmidiframe.cpp,v 1.9 2000/09/03 05:42:45 waba Exp $
+   $Id: kmidiframe.cpp,v 1.15.2.1 2002/04/14 12:56:21 lukas Exp $
 
    Copyright 1997, 1998 Bernd Johannes Wuebben math.cornell.edu
 
@@ -40,6 +40,7 @@
 #include "kmidi.h"
 
 #include "kmidiframe.h"
+#include <kpopupmenu.h>
 
 
 int menubarheight = 0;
@@ -51,7 +52,6 @@ int fixframesizecount = 0;
 //QFont default_font("Helvetica", 10, QFont::Bold);
 
 
-extern KMidi *kmidi;
 KMidiFrame *kmidiframe;
 
 DockWidget*     dock_widget;
@@ -63,7 +63,7 @@ KMidiFrame::KMidiFrame( const char *name ) :
     menuBar = new KMenuBar(this);
 
     QPopupMenu *fileMenu = new QPopupMenu;
-    menuBar->insertItem("&File", fileMenu);
+    menuBar->insertItem(i18n("&File"), fileMenu);
 
     fileMenu->insertItem( i18n("&Open..."), this,
                         SLOT(file_Open()), CTRL+Key_O );
@@ -73,33 +73,33 @@ KMidiFrame::KMidiFrame( const char *name ) :
     kmidi = new KMidi(this, "_kmidi" );
 
     view_options = new QPopupMenu();
-    CHECK_PTR( view_options );
+    Q_CHECK_PTR( view_options );
     view_options->setCheckable( TRUE );
     menuBar->insertItem( i18n("&View"), view_options );
     connect( view_options, SIGNAL(activated(int)), this, SLOT(doViewMenuItem(int)) );
     connect( view_options, SIGNAL(aboutToShow()), this, SLOT(fixViewItems()) );
-	m_on_id = view_options->insertItem(  i18n("Meter shown") );
+	m_on_id = view_options->insertItem(  i18n("Meter Shown") );
 	view_options->setWhatsThis(m_on_id, i18n("When you can see this<br>\n"
 				"menu, the channel meter<br>\n"
 				"is always turned on.") );
-	m_off_id = view_options->insertItem(  i18n("Meter off") );
+	m_off_id = view_options->insertItem(  i18n("Meter Off") );
 	view_options->setWhatsThis(m_off_id, i18n("This turns off the channel<br>\n"
 				"meter display, and also hides<br>\n"
 				"this menu bar.") );
 	view_options->insertSeparator();
-	i_on_id = view_options->insertItem(  i18n("Info shown") );
+	i_on_id = view_options->insertItem(  i18n("Info Shown") );
 	view_options->setWhatsThis(i_on_id, i18n("Shows a window at the<br>\n"
 				"bottom with info about the<br>\n"
 				"midi file being played.") );
-	i_off_id = view_options->insertItem(  i18n("Info off") );
+	i_off_id = view_options->insertItem(  i18n("Info Off") );
 	view_options->setWhatsThis(i_off_id, i18n("Turns off the info window<br>\n"
 				"at the bottom.") );
     view_level = new QPopupMenu();
-    CHECK_PTR( view_level );
+    Q_CHECK_PTR( view_level );
     view_level->setCheckable( TRUE );
     view_options->insertSeparator();
-    view_options->insertItem( i18n("Info level"), view_level);
-        view_level->insertItem( i18n("Lyrics only") , 100);
+    view_options->insertItem( i18n("Info Level"), view_level);
+        view_level->insertItem( i18n("Lyrics Only") , 100);
 	view_level->setWhatsThis(100, i18n("The info window will<br>\n"
 				"show only lyrics, if any,<br>\n"
 				"and the name of the midi file.") );
@@ -131,35 +131,35 @@ KMidiFrame::KMidiFrame( const char *name ) :
 
 
     stereo_options = new QPopupMenu();
-    CHECK_PTR( stereo_options );
+    Q_CHECK_PTR( stereo_options );
     stereo_options->setCheckable( TRUE );
     menuBar->insertItem( i18n("Stereo"), stereo_options );
     connect( stereo_options, SIGNAL(activated(int)), this, SLOT(doStereoMenuItem(int)) );
     connect( stereo_options, SIGNAL(aboutToShow()), this, SLOT(fixStereoItems()) );
-	stereo_options->insertItem(  i18n("No stereo patch"), 110 );
+	stereo_options->insertItem(  i18n("No Stereo Patch"), 110 );
 	stereo_options->setWhatsThis(110, i18n("Prevents playing the<br>\n"
 				"second instrument for those<br>\n"
 				"patches that have two<br>\n"
 				"(you probably don't want<br>\n"
 				"to choose this option).") );
-	stereo_options->insertItem(  i18n("Normal stereo") , 111);
+	stereo_options->insertItem(  i18n("Normal Stereo") , 111);
 	stereo_options->setWhatsThis(111, i18n("Plays both instruments<br>\n"
 				"for those (sf2) patches<br>\n"
 				"which have two.") );
-	stereo_options->insertItem(  i18n("Extra stereo") , 112);
+	stereo_options->insertItem(  i18n("Extra Stereo") , 112);
 	stereo_options->setWhatsThis(112, i18n("For keyboard instruments,<br>\n"
 				"lower notes come from the left<br>\n"
 				"For other instruments, position is<br>\n"
 				"made a function of note<br>\n"
 				"velocity.") );
 	stereo_options->insertSeparator();
-	stereo_options->insertItem(  i18n("Surround stereo") , 113);
+	stereo_options->insertItem(  i18n("Surround Stereo") , 113);
 	stereo_options->setWhatsThis(112, i18n("Extra stereo, echo, and<br>" \
 				"detuned notes are spread out more<br>" \
 				"to left and right.") );
 
     reverb_options = new QPopupMenu();
-    CHECK_PTR( reverb_options );
+    Q_CHECK_PTR( reverb_options );
     reverb_options->setCheckable( TRUE );
     menuBar->insertItem( i18n("Reverb"), reverb_options );
     connect( reverb_options, SIGNAL(activated(int)), this, SLOT(doReverbMenuItem(int)) );
@@ -170,14 +170,14 @@ KMidiFrame::KMidiFrame( const char *name ) :
 				"they are ended by playing<br>\n"
 				"through the ends of their<br>\n"
 				"patches (which may cause some<br>\n"
-				"clicking).  The wet setting makes<br>\n"
-				"notes continues to the ends of<br>\n"
+				"clicking). The wet setting makes<br>\n"
+				"notes continue to the ends of<br>\n"
 				"their volume envelopes.") );
     reverb_level = new QPopupMenu();
-    CHECK_PTR( reverb_level );
+    Q_CHECK_PTR( reverb_level );
     reverb_level->setCheckable( TRUE );
     reverb_options->insertSeparator();
-    reverb_options->insertItem( i18n("Reverb level"), reverb_level);
+    reverb_options->insertItem( i18n("Reverb Level"), reverb_level);
         reverb_level->insertItem( i18n("default") , 160);
 	reverb_level->setWhatsThis(160, i18n("The reverberation level<br>\n"
 				"is set according to the midi<br>\n"
@@ -206,7 +206,7 @@ KMidiFrame::KMidiFrame( const char *name ) :
 					       "played to get the effect<br>\n"
 					       "of reverberation.") );
     echo_level = new QPopupMenu();
-    CHECK_PTR( echo_level );
+    Q_CHECK_PTR( echo_level );
     echo_level->setCheckable( TRUE );
     reverb_options->insertSeparator();
     reverb_options->insertItem( i18n("Echo level"), echo_level);
@@ -232,13 +232,13 @@ KMidiFrame::KMidiFrame( const char *name ) :
 
 
     chorus_options = new QPopupMenu();
-    CHECK_PTR( chorus_options );
+    Q_CHECK_PTR( chorus_options );
     chorus_options->setCheckable( TRUE );
     menuBar->insertItem( i18n("Chorus"), chorus_options );
     connect( chorus_options, SIGNAL(activated(int)), this, SLOT(doChorusMenuItem(int)) );
     connect( chorus_options, SIGNAL(aboutToShow()), this, SLOT(fixChorusItems()) );
     chorus_level = new QPopupMenu();
-    CHECK_PTR( chorus_level );
+    Q_CHECK_PTR( chorus_level );
     chorus_level->setCheckable( TRUE );
     chorus_options->insertItem( i18n("Chorus level"), chorus_level);
     chorus_level->insertItem( i18n("default") , 170);
@@ -261,18 +261,18 @@ KMidiFrame::KMidiFrame( const char *name ) :
     connect( chorus_level, SIGNAL(activated(int)), this, SLOT(doChorusLevel(int)) );
     connect( chorus_level, SIGNAL(aboutToShow()), this, SLOT(fixChorusLevelItems()) );
     chorus_options->insertSeparator();
-    chorus_options->insertItem(  i18n("No detune"), 140 );
+    chorus_options->insertItem(  i18n("No Detune"), 140 );
     chorus_options->setWhatsThis(140, i18n("Prevents playing extra<br>\n"
 					   "detuned notes for chorus effect.") );
-    chorus_options->insertItem(  i18n("Normal detune") , 141);
+    chorus_options->insertItem(  i18n("Normal Detune") , 141);
     chorus_options->setWhatsThis(141, i18n("Extra detuned notes are<br>\n"
 					   "played to get the effect<br>\n"
 					   "of chorusing") );
     detune_level = new QPopupMenu();
-    CHECK_PTR( detune_level );
+    Q_CHECK_PTR( detune_level );
     detune_level->setCheckable( TRUE );
     chorus_options->insertSeparator();
-    chorus_options->insertItem( i18n("Detune level"), detune_level);
+    chorus_options->insertItem( i18n("Detune Level"), detune_level);
     detune_level->insertItem( i18n("default") , 150);
     detune_level->setWhatsThis(150, i18n("The level for detuned notes<br>\n"
 					 "is set according to the midi<br>\n"
@@ -295,12 +295,12 @@ KMidiFrame::KMidiFrame( const char *name ) :
     connect( detune_level, SIGNAL(aboutToShow()), this, SLOT(fixDetuneLevelItems()) );
 
     volume_options = new QPopupMenu();
-    CHECK_PTR( volume_options );
+    Q_CHECK_PTR( volume_options );
     //volume_options->setCheckable( TRUE );
     menuBar->insertItem( i18n("Volume"), volume_options );
     //connect( volume_options, SIGNAL(activated(int)), this, SLOT(doVolumeMenuItem(int)) );
     volume_curve = new QPopupMenu();
-    CHECK_PTR( volume_curve );
+    Q_CHECK_PTR( volume_curve );
     volume_curve->setCheckable( TRUE );
     volume_options->insertItem( i18n("Volume Curve"), volume_curve);
     connect( volume_curve, SIGNAL(activated(int)), this, SLOT(doVolumeCurve(int)) );
@@ -316,7 +316,7 @@ KMidiFrame::KMidiFrame( const char *name ) :
 				"changes the volume exponentially." ) );
     volume_options->insertSeparator();
     expression_curve = new QPopupMenu();
-    CHECK_PTR( expression_curve );
+    Q_CHECK_PTR( expression_curve );
     expression_curve->setCheckable( TRUE );
     volume_options->insertItem( i18n("Expression Curve"), expression_curve);
     connect( expression_curve, SIGNAL(activated(int)), this, SLOT(doExpressionCurve(int)) );
