@@ -1,7 +1,7 @@
 /*
  *        kmidi
  *
- * $Id: log.cpp,v 1.18 2001/05/13 01:55:26 gebauer Exp $
+ * $Id: log.cpp,v 1.19 2001/09/02 20:55:16 bruggie Exp $
  *            Copyright (C) 1997  Bernd Wuebben
  *                 wuebben@math.cornel.edu 
  *
@@ -36,7 +36,7 @@ LogWindow::LogWindow(QWidget *parent, const char *name)
   text_window = new QMultiLineEdit(this,"logwindow");
   text_window->setFocusPolicy ( QWidget::NoFocus );
   text_window->setReadOnly( TRUE );
-  text_window->setUndoEnabled( FALSE );
+  text_window->setUndoRedoEnabled( FALSE );
   //text_window->setMaxLineLength( 24 );
   text_window->setMaxLines( 110 ); // text_window->numRows() ??
 
