@@ -1,7 +1,7 @@
 /*
    kmidi
 
-   $Id: playlist.cpp,v 1.31 2000/12/01 21:59:02 malte Exp $
+   $Id: playlist.cpp,v 1.34 2002/01/06 04:17:10 mueller Exp $
 
    Copyright 1997 Bernd Johannes Wuebben math.cornell.edu
 
@@ -29,7 +29,7 @@
 
 #include <kconfig.h>
 #include <klocale.h>
-#include <kstddirs.h>
+#include <kstandarddirs.h>
 #include <kmessagebox.h>
 
 #include "playlist.h"
@@ -60,7 +60,7 @@ PlaylistEdit::PlaylistEdit(const char *name, QStringList *playlist,
   what = new QWhatsThis(this);
 
   QPopupMenu *file = new QPopupMenu;
-  CHECK_PTR( file );
+  Q_CHECK_PTR( file );
 
   snpopup = new QFrame( this ,0, WType_Popup);
   snpopup->setFrameStyle( QFrame::PopupPanel|QFrame::Raised );
@@ -69,7 +69,7 @@ PlaylistEdit::PlaylistEdit(const char *name, QStringList *playlist,
   newEdit = new QLineEdit( snpopup, "_editnew" );
 
   QLabel *labsavename = new QLabel(snpopup);
-  labsavename->setText("enter new name");
+  labsavename->setText(i18n("Enter new name"));
   newEdit->setGeometry(10,10, 150, 30);
   labsavename->setGeometry(20,10+30, 150, 30);
   connect( newEdit, SIGNAL( returnPressed() ), this, SLOT( newPlaylist() ) );
@@ -99,14 +99,14 @@ PlaylistEdit::PlaylistEdit(const char *name, QStringList *playlist,
 				"and leave the play list editor.") );
 
   view = new QPopupMenu;
-  CHECK_PTR( view );
+  Q_CHECK_PTR( view );
   view->insertItem( i18n("All files"), this, SLOT(setFilter()), 0, 50 );
 	view->setWhatsThis(50, i18n("Choose whether the file<br>\n"
 				"list should show only uncompressed<br>\n"
 				"midi files or all files.") );
 
   QPopupMenu *edit = new QPopupMenu;
-  CHECK_PTR( edit );
+  Q_CHECK_PTR( edit );
   edit->insertItem( i18n("Clear"), this, SLOT(clearPlist()), 0, 51 );
 	edit->setWhatsThis(51, i18n("Discard the contents<br>\n"
 				"of the current play list.") );
@@ -123,7 +123,7 @@ PlaylistEdit::PlaylistEdit(const char *name, QStringList *playlist,
 				"file from the play list.") );
 
   menu = new KMenuBar( this );
-  CHECK_PTR( menu );
+  Q_CHECK_PTR( menu );
   menu->insertItem( i18n("&File"), file );
   menu->insertItem( i18n("&View"), view );
   menu->insertItem( i18n("&Edit"), edit );
