@@ -30,11 +30,11 @@
 #include <qpushbutton.h>
 #include <kconfig.h>
 #include <kglobal.h>
-#include <kstddirs.h>
+#include <kstandarddirs.h>
 #include <klocale.h>
 #include <kdialog.h>
 #include <kdebug.h>
-#include <kapp.h>
+#include <kapplication.h>
 #include <kfile.h>
 #include <qtextstream.h>
 #include <kiconloader.h>
@@ -60,12 +60,12 @@ KMixConfig::KMixConfig(QWidget *parent, const char *name)
 
   // Save profile
   QHBoxLayout *profLayout = new QHBoxLayout( restLayout, 5 );
-  QPushButton *saveProf = new QPushButton( i18n("Save current volumes"), restGrp );
+  QPushButton *saveProf = new QPushButton( i18n("Save Current Volumes"), restGrp );
   profLayout->addWidget( saveProf );
   connect( saveProf, SIGNAL(clicked()), this, SLOT(saveVolumes()) );
 
   // Load profile
-  QPushButton *loadProf = new QPushButton( i18n("Load volumes"), restGrp );
+  QPushButton *loadProf = new QPushButton( i18n("Load Volumes"), restGrp );
   profLayout->addWidget( loadProf );
   connect( loadProf, SIGNAL(clicked()), this, SLOT(loadVolumes()) );
 
@@ -211,8 +211,7 @@ extern "C"
 {
     KCModule *create_kmix(QWidget *parent, const char *name)
     {
-      KGlobal::locale()->insertCatalogue("kcmkmix");
-      return new KMixConfig(parent, name);
+      return new KMixConfig(parent, "kcmkmix");
     }
 
     void init_kmix()
