@@ -1,7 +1,7 @@
 /*
  * KMix -- KDE's full featured mini mixer
  *
- * $Id: kmix.cpp,v 1.111.2.1 2001/10/25 22:36:36 waba Exp $
+ * $Id: kmix.cpp,v 1.119 2002/01/26 13:23:03 deller Exp $
  *
  * Copyright (C) 2000 Stefan Schimanski <schimmi@kde.org>
  * Copyright (C) 2001 Preston Brown <pbrown@kde.org>
@@ -43,7 +43,6 @@
 #include <kpanelapplet.h>
 #include <kpopupmenu.h>
 #include <khelpmenu.h>
-#include <kiconloader.h>
 #include <kdebug.h>
 #include <kaccel.h>
 
@@ -120,25 +119,26 @@ KMixWindow::KMixWindow()
        show();
    else
        hide();
+       
+   connect( kapp, SIGNAL( aboutToQuit()), SLOT( saveConfig()));
 }
 
 
 KMixWindow::~KMixWindow()
 {
-    saveConfig();
 }
 
 
 void KMixWindow::initActions()
 {
     // file menu
-    (void)new KAction( i18n("&New mixer tab"), "filenew", 0, this,
+    (void)new KAction( i18n("&New Mixer Tab"), "filenew", 0, this,
                        SLOT(newMixer()), actionCollection(), "file_new_tab" );
-    (void)new KAction( i18n("&Close mixer tab"), "fileclose", 0, this,
+    (void)new KAction( i18n("&Close Mixer Tab"), "fileclose", 0, this,
                        SLOT(closeMixer()), actionCollection(), "file_close_tab" );
-    (void)new KAction( i18n("&Restore default volumes"), 0, this, SLOT(loadVolumes()),
+    (void)new KAction( i18n("&Restore Default Volumes"), 0, this, SLOT(loadVolumes()),
                        actionCollection(), "file_load_volume" );
-    (void)new KAction( i18n("&Save current volumes as default"), 0, this, SLOT(saveVolumes()),
+    (void)new KAction( i18n("&Save Current Volumes as Default"), 0, this, SLOT(saveVolumes()),
                        actionCollection(), "file_save_volume" );
     KStdAction::quit( this, SLOT(quit()), actionCollection());
 
@@ -323,11 +323,13 @@ void KMixWindow::loadConfig()
 
        }
 
-       KMixerWidget *mw = new KMixerWidget( id, mixer, mixerName, mixerNum, 
-                                            false, KPanelApplet::Up, this );
-       mw->setName( name );
-       mw->loadConfig( config, *tab );
-       insertMixerWidget( mw );
+       // only if an actual mixer device is found for the config entry
+       if (mixer) {
+           KMixerWidget *mw = new KMixerWidget( id, mixer, mixerName, mixerNum, false, KPanelApplet::Up, this );
+           mw->setName( name );
+           mw->loadConfig( config, *tab );
+           insertMixerWidget( mw );
+       }
    }
 
    // restore window size and position
@@ -388,7 +390,11 @@ void KMixWindow::closeEvent ( QCloseEvent * e )
         kapp->ref(); // prevent KMainWindow from closing the app
         // </evil>
     } else
+    {
         kapp->quit(); // force the application to quit
+        e->ignore(); // don't close the window, isVisible() is called in saveConfig()
+        return;
+    }
 
     KMainWindow::closeEvent( e );
 }
@@ -437,9 +443,10 @@ void KMixWindow::closeMixer()
 void KMixWindow::newMixer()
 {
    QStringList lst;
+   Mixer *mixer;
 
-   int n=1;
-   for (Mixer *mixer=m_mixers.first(); mixer!=0; mixer=m_mixers.next())
+   int n = 1;
+   for (mixer=m_mixers.first(); mixer; mixer=m_mixers.next())
    {
       QString s;
       s.sprintf("%i. %s", n, mixer->mixerName().ascii());
@@ -449,20 +456,21 @@ void KMixWindow::newMixer()
 
    bool ok = FALSE;
    QString res = QInputDialog::getItem( i18n("Mixers"),
-                                        i18n( "Available mixers" ), lst,
-                                        1, TRUE, &ok, this );
+                                        i18n("Available mixers"),
+					lst, 1, FALSE, &ok, this );
    if ( ok )
    {
        // valid mixer?
-       Mixer *mixer = m_mixers.at( lst.findIndex( res ) );
+       mixer = m_mixers.at( lst.findIndex( res ) );
        if (!mixer) {
            KMessageBox::sorry( this, i18n("Invalid mixer entered.") );
            return;
        }
 
        // ask for description
-       QString name = QInputDialog::getText( i18n("Description"), i18n( "Description" ),
-                                             mixer->mixerName(), &ok, this );
+       QString name = QInputDialog::getText(
+                        i18n("Description"), i18n("Description"),
+                        QLineEdit::Normal, mixer->mixerName(), &ok, this );
       if ( ok ) {
 
           // create mixer widget
