@@ -25,7 +25,7 @@
 #include <qwidget.h>
 #include <kaction.h>
 #include <kpanelapplet.h>
-#include <qlist.h>
+#include <qptrlist.h>
 #include <kcolordialog.h>
 
 #include "colorwidget.h"
@@ -77,6 +77,7 @@ class KMixApplet : public KPanelApplet
    void updateLayoutNow(); 
    void selectMixer();
    void applyColors();
+   void applyDirection();
   
   protected:
    void resizeEvent( QResizeEvent * );
@@ -88,11 +89,13 @@ class KMixApplet : public KPanelApplet
    QTimer *m_layoutTimer;
    int m_lockedLayout;
    ColorWidget *m_pref;
-   bool insideOut; //  reverses direction of sliders and icon position
+   bool reversedDir; //  reverses direction of sliders and icon position
    void popupDirectionChange(Direction);
+   Direction checkReverse(Direction);
+   void setColors();
 
    static int s_instCount;
-   static QList<Mixer> *s_mixers;
+   static QPtrList<Mixer> *s_mixers;
    static QTimer *s_timer;    
 
    KMixerWidget::Colors m_colors;
