@@ -31,6 +31,7 @@
 #include <kglobalaccel.h>
 #include <kkeydialog.h>
 
+#include <qcursor.h>
 #include <qslider.h>
 #include <qlabel.h>
 #include <qlayout.h>
@@ -68,7 +69,7 @@ MixDeviceWidget::MixDeviceWidget(Mixer *mixer, MixDevice* md,
    m_actions = new KActionCollection( this );
 
    if (parent->isA("KMixerWidget"))
-       new KToggleAction( i18n("&Split channels"), 0, this, SLOT(toggleStereoLinked()),
+       new KToggleAction( i18n("&Split Channels"), 0, this, SLOT(toggleStereoLinked()),
                       m_actions, "stereo" );
    if (parent->isA("KMixerWidget"))
        new KAction( i18n("&Hide"), 0, this, SLOT(setDisabled()), m_actions, "hide" );
@@ -77,15 +78,15 @@ MixDeviceWidget::MixDeviceWidget(Mixer *mixer, MixDevice* md,
    a->connect( a, SIGNAL(toggled(bool)), this, SLOT(setMuted(bool)) );
 
    if (parent->isA("KMixerWidget"))
-       new KAction( i18n("Show &all"), 0, parent, SLOT(showAll()), m_actions, "show_all" );
+       new KAction( i18n("Show &All"), 0, parent, SLOT(showAll()), m_actions, "show_all" );
 
    if( m_mixdevice->isRecordable() )
    {
-      a = new KToggleAction( i18n("Set &record source"), 0, 0, 0, m_actions, "recsrc" );
+      a = new KToggleAction( i18n("Set &Record Source"), 0, 0, 0, m_actions, "recsrc" );
       a->connect( a, SIGNAL(toggled(bool)), this, SLOT(setRecsrc(bool)) );
    }
 
-   new KAction( i18n("Define &keys"), 0, this, SLOT(defineKeys()), m_actions, "keys" );
+   new KAction( i18n("Define &Keys"), 0, this, SLOT(defineKeys()), m_actions, "keys" );
 
    // create widgets
    createWidgets( showMuteLED, showRecordLED );
@@ -95,20 +96,29 @@ MixDeviceWidget::MixDeviceWidget(Mixer *mixer, MixDevice* md,
    connect( m_updateTimer, SIGNAL(timeout()), this, SLOT(update()) );
    m_updateTimer->start( 200, FALSE );
 
-   m_keys=new KGlobalAccel(this,"Keys");
-   m_keys->insertItem( i18n( "Increase volume" ), "Increase volume", "" );
-   m_keys->insertItem( i18n( "Decrease volume" ), "Decrease volume", "" );
-   m_keys->insertItem( i18n( "Toggle mute" ), "Toggle mute", "" );
-   
-   m_keys->connectItem( "Toggle mute", this, SLOT( toggleMuted() ) );
-   m_keys->connectItem( "Increase volume", this, SLOT( increaseVolume() ) );
-   m_keys->connectItem( "Decrease volume", this, SLOT( decreaseVolume() ) );
+   m_keys = new KGlobalAccel( this, "Keys" );
+   m_keys->insert( "Increase volume", i18n( "Increase volume" ), QString::null,
+      KShortcut(), KShortcut(), this, SLOT( increaseVolume() ) );
+   m_keys->insert( "Decrease volume", i18n( "Decrease volume" ), QString::null,
+      KShortcut(), KShortcut(), this, SLOT( decreaseVolume() ) );
+   m_keys->insert( "Toggle mute", i18n( "Toggle mute" ), QString::null,
+      KShortcut(), KShortcut(), this, SLOT( toggleMuted() ) );
+   // No need for m_keys->readSettings(), the keys are loaded in KMixerWidget::loadConfig, see kmixerwidget.cpp
+   m_keys->updateConnections();
 };
 
 MixDeviceWidget::~MixDeviceWidget()
 {
 }
 
+
+#define GET_NEWLAYOUT(x) \
+	QBoxLayout *x; \
+	if ((m_direction == KPanelApplet::Up) || (m_direction == KPanelApplet::Down)) \
+		x = new QHBoxLayout( layout ); \
+       	else \
+		x = new QVBoxLayout( layout );
+
 void MixDeviceWidget::createWidgets( bool showMuteLED, bool showRecordLED )
 {
    QBoxLayout *layout;
@@ -122,7 +132,7 @@ void MixDeviceWidget::createWidgets( bool showMuteLED, bool showRecordLED )
       m_iconLabel = 0L;
       setIcon( m_mixdevice->type() );
       layout->addWidget( m_iconLabel );
-      m_iconLabel->installEventFilter( this );
+      //m_iconLabel->installEventFilter( this );
       QToolTip::add( m_iconLabel, m_mixdevice->name() );
    } //  otherwise it is created after the slider
 
@@ -140,17 +150,14 @@ void MixDeviceWidget::createWidgets( bool showMuteLED, bool showRecordLED )
    if (!showMuteLED) m_muteLED->hide();
    m_muteLED->setFixedSize( QSize(16, 16) );
    QToolTip::add( m_muteLED, i18n("Muting") );
-   layout->addWidget( m_muteLED );
+   GET_NEWLAYOUT( ledlayout );
+   ledlayout->addWidget( m_muteLED );
    m_muteLED->installEventFilter( this );
    connect( m_muteLED, SIGNAL(stateChanged(bool)), this, SLOT(setUnmuted(bool)) );
 
    // create sliders
    layout->addSpacing( 1 );
-   QBoxLayout *sliders;
-   if ((m_direction == KPanelApplet::Up) || (m_direction == KPanelApplet::Down))
-     sliders = new QHBoxLayout( layout );
-   else
-     sliders = new QVBoxLayout( layout );
+   GET_NEWLAYOUT( sliders );
    for( int i = 0; i < m_mixdevice->getVolume().channels(); i++ )
    {
       int maxvol = m_mixdevice->getVolume().maxVolume();
@@ -160,13 +167,15 @@ void MixDeviceWidget::createWidgets( bool showMuteLED, bool showRecordLED )
                                     m_mixdevice->getVolume( i ),
                                     m_direction,
                                     this, m_mixdevice->name().ascii() );
-      else
+      else {
          slider = new QSlider( 0, maxvol, maxvol/10,
                                maxvol - m_mixdevice->getVolume( i ),
                                (m_direction == KPanelApplet::Up ||
                                 m_direction == KPanelApplet::Down) ?
                                 QSlider::Vertical : QSlider::Horizontal,
                                this, m_mixdevice->name().ascii() );
+	 slider->setMinimumSize( slider->sizeHint() );
+      }
 
       QToolTip::add( slider, m_mixdevice->name() );
       slider->installEventFilter( this );
@@ -195,7 +204,8 @@ void MixDeviceWidget::createWidgets( bool showMuteLED, bool showRecordLED )
       QToolTip::add( m_recordLED, i18n("Recording") );
       m_recordLED->setFixedSize( QSize(16, 16) );
 
-      layout->addWidget( m_recordLED );
+      GET_NEWLAYOUT( reclayout );
+      reclayout->addWidget( m_recordLED );
       connect(m_recordLED, SIGNAL(stateChanged(bool)), this, SLOT(setRecsrc(bool)));
       m_recordLED->installEventFilter( this );
    }
@@ -205,6 +215,7 @@ void MixDeviceWidget::createWidgets( bool showMuteLED, bool showRecordLED )
       if ( showRecordLED ) layout->addSpacing( 16 );
    }
 }
+#undef GET_NEWLAYOUT
 
 QPixmap MixDeviceWidget::getIcon( int icon )
 {
@@ -215,9 +226,9 @@ QPixmap MixDeviceWidget::getIcon( int icon )
       case MixDevice::BASS:
          miniDevPM = UserIcon("mix_bass"); break;
       case MixDevice::CD:
-         miniDevPM = UserIcon("mix_cd");        break;
+         miniDevPM = UserIcon("mix_cd"); break;
       case MixDevice::EXTERNAL:
-         miniDevPM = UserIcon("mix_ext");       break;
+         miniDevPM = UserIcon("mix_ext"); break;
       case MixDevice::MICROPHONE:
          miniDevPM = UserIcon("mix_microphone");break;
       case MixDevice::MIDI:
@@ -272,7 +283,7 @@ void MixDeviceWidget::setIcon( int icon )
 
 bool MixDeviceWidget::isLabeled()
 {
-   return m_label->isVisible();
+   return !m_label->isHidden();
 }
 
 bool MixDeviceWidget::isDisabled()
@@ -362,7 +373,7 @@ void MixDeviceWidget::setTicks( bool ticks )
 
 void MixDeviceWidget::setIcons(bool value)
 {
-   if ( m_iconLabel->isVisible()!=value )
+   if ( ( !m_iconLabel->isHidden()) !=value ) 
    {
       if (value)
          m_iconLabel->show();
@@ -390,7 +401,7 @@ void MixDeviceWidget::setMutedColors( QColor high, QColor low, QColor back )
     }
 }
 
-KGlobalAccel *MixDeviceWidget::keys(void)
+KGlobalAccel *MixDeviceWidget::keys( void )
 {
     return m_keys;
 }
@@ -450,8 +461,11 @@ void MixDeviceWidget::setDisabled( bool value )
 
 void MixDeviceWidget::defineKeys()
 {
-   if (m_keys)
-      KKeyDialog::configureKeys(m_keys,false);
+   if (m_keys) {
+      KKeyDialog::configure(m_keys, 0, false);
+      // The keys are saved in KMixerWidget::saveConfig, see kmixerwidget.cpp
+      m_keys->updateConnections();
+   }
 }
 
 void MixDeviceWidget::increaseVolume()
@@ -555,7 +569,7 @@ void MixDeviceWidget::update()
 void MixDeviceWidget::contextMenu()
 {
    KPopupMenu *menu = new KPopupMenu( this );
-   menu->insertTitle( SmallIcon( "kmix" ), i18n("Device settings") );
+   menu->insertTitle( SmallIcon( "kmix" ), i18n("Device Settings") );
 
    if ( m_sliders.count()>1 )
    {
