@@ -133,7 +133,7 @@ int Mixer_OSS::openMixer()
                   readVolumeFromHW( idx, vol );
                   MixDevice* md =
                     new MixDevice( idx, vol, recmask & ( 1 << idx ),
-                                   QString(MixerDevNames[idx]),
+                                   i18n(MixerDevNames[idx]),
                                    MixerChannelTypes[idx]);
                   md->setRecsrc( isRecsrcHW( idx ) );
                   m_mixDevices.append( md );
@@ -193,7 +193,7 @@ QString Mixer_OSS::errorText(int mixer_error)
   switch (mixer_error)
     {
     case ERR_PERM:
-      l_s_errmsg = i18n("kmix: You have no permission to access the mixer device.\n" \
+      l_s_errmsg = i18n("kmix: You do not have permission to access the mixer device.\n" \
                         "Login as root and do a 'chmod a+rw /dev/mixer*' to allow the access.");
       break;
     case ERR_OPEN:
