@@ -1,7 +1,7 @@
 /*
  *              KSCD -- a simpole cd player for the KDE project
  *
- * $Id: docking.cpp,v 1.23 2001/03/25 04:23:00 tibirna Exp $
+ * $Id: docking.cpp,v 1.24 2002/01/06 04:10:13 mueller Exp $
  *
  *              Copyright (C) 1997 Bernd Johannes Wuebben
  *                      wuebben@math.cornell.edu
@@ -24,7 +24,7 @@
 #include "kscd.h"
 
 #include <qtooltip.h>
-#include <kapp.h>
+#include <kapplication.h>
 
 #include "docking.h"
 #include <klocale.h>
