@@ -1,5 +1,5 @@
 /*
- * $Id: cdrom.c,v 1.6 2001/02/04 10:42:35 dfoerste Exp $
+ * $Id: cdrom.c,v 1.13 2002/02/26 17:49:13 neil Exp $
  *
  * This file is part of WorkMan, the civilized CD player library
  * (c) 1991-1997 by Steven Grimm (original author)
@@ -27,7 +27,7 @@
  * platform- or drive-dependent code here.
  */
 
-static char cdrom_id[] = "$Id: cdrom.c,v 1.6 2001/02/04 10:42:35 dfoerste Exp $";
+static char cdrom_id[] = "$Id: cdrom.c,v 1.13 2002/02/26 17:49:13 neil Exp $";
 
 #include <errno.h>
 #include <stdio.h>
@@ -45,6 +45,7 @@ static char cdrom_id[] = "$Id: cdrom.c,v 1.6 2001/02/04 10:42:35 dfoerste Exp $"
 #include "include/wm_platform.h"
 #include "include/wm_helpers.h"
 #include "include/wm_cdinfo.h"
+#include "include/wm_cdtext.h"
 
 #ifdef CAN_CLOSE
 #include <fcntl.h>
@@ -181,10 +182,17 @@ read_toc()
         struct wm_playlist *l;
         int    i;
         int    pos;
+
+	if(drive.get_trackcount == NULL)
+	{
+		perror("trackcount: function pointer NULL");
+		return (NULL);
+	}
+
 	if ((drive.get_trackcount)(&drive, &thiscd.ntracks) < 0)
 	{
 		perror("trackcount");
-		return (NULL);
+		return NULL ;
 	}
 
 	thiscd.artist[0] = thiscd.cdname[0] = '\0';
@@ -216,6 +224,12 @@ read_toc()
 
 	for (i = 0; i < thiscd.ntracks; i++)
 	{
+		if(drive.get_trackinfo == NULL)
+		{
+			perror("CD track info read: function pointer null");
+			return (NULL);
+		}
+
 		if ((drive.get_trackinfo)(&drive, i + 1, &thiscd.trk[i].data,
 					&thiscd.trk[i].start) < 0)
 		{
@@ -234,6 +248,12 @@ read_toc()
 		thiscd.trk[i].section = 0;
 	}
 
+	if(drive.get_cdlen == NULL)
+	{
+		perror("CD length read: function pointer null");
+		return (NULL);
+	}
+
 	if ((drive.get_cdlen)(&drive, &thiscd.trk[i].start) < 0)
 	{
 		perror("CD length read");
@@ -280,15 +300,22 @@ wm_cd_status( void )
 	enum wm_cd_modes		mode;
 	int			status, trackno = cur_track;
 	int			ret = WM_CDS_DISC_READY;
-
-	/* Open the drive.  This returns 1 if the device isn't ready. */
-
-	status = wmcd_open(&drive);
-
-	if (status < 0)
-		return (status);
-	if (status > 0)
-		return (WM_CDS_NO_DISC);
+        
+	if( cur_cdmode == WM_CDM_DEVICECHANGED )
+	  {
+	    /* Don't open the device now */
+	    close( drive.fd );
+	    drive.fd = -1;
+	    status = 0;
+	    wmcd_open( &drive );
+	  } else {
+	    /* Open the drive.  This returns 1 if the device isn't ready. */
+	    status = wmcd_open( &drive );
+	    if (status < 0)
+	      return (status);
+	    if (status > 0)
+	      return (WM_CDS_NO_DISC);
+	  }
 
 	/* If the user hit the stop button, don't pass PLAYING as oldmode.
          * Likewise, if we've just started playing, don't remember that
@@ -298,6 +325,12 @@ wm_cd_status( void )
 	if( (cur_cdmode == WM_CDM_STOPPED) || (cur_cdmode == WM_CDM_PLAYING) )
 		oldmode = cur_cdmode;
 
+	if(drive.get_drive_status == NULL)
+	{
+		perror("CD get drive status: function pointer NULL");
+		return (-1);
+	}
+
 	if( (drive.get_drive_status)(&drive, oldmode, &mode, &cur_frame,
 					&trackno, &cur_index) < 0)
 	{
@@ -306,45 +339,39 @@ wm_cd_status( void )
 	}
 	oldmode = mode;
 
-	if (mode == WM_CDM_EJECTED || mode == WM_CDM_UNKNOWN)
+        if ((mode == WM_CDM_EJECTED || mode == WM_CDM_UNKNOWN) && (cur_cdmode != WM_CDM_DEVICECHANGED) )
 	{
 		cur_cdmode = WM_CDM_EJECTED;
 		cur_track = -1;
 		cur_cdlen = cur_tracklen = 1;
 		cur_pos_abs = cur_pos_rel = cur_frame = 0;
 
-		if (exit_on_eject)
-			exit(0);
-
 		return (WM_CDS_NO_DISC);
 	}
 
-	/* If there wasn't a CD before and there is now, learn about it. */
-	if (cur_cdmode == WM_CDM_EJECTED)
+	/* If there wasn't a CD before and there is now, learn about it. 
+	 * If the device has changed, this will close the old fd and     
+         * re-open the device before gathering information */
+	if (cur_cdmode == WM_CDM_EJECTED || cur_cdmode == WM_CDM_DEVICECHANGED)
 	{
-		cur_pos_rel = cur_pos_abs = 0;
 
+	        cur_track = -1;
+		cur_pos_abs = cur_pos_rel = cur_frame = 0;
+
+		cur_pos_rel = cur_pos_abs = 0;
 
 		status = wmcd_reopen( &drive );
 
 		if ((cd = read_toc()) == NULL)
                 {
-		        wm_lib_message(WM_MSG_LEVEL_DEBUG|WM_MSG_CLASS_MISC,"status: returned toc was NULL\n");
-			if (exit_on_eject)
-			{
-				exit(-1);
-			} else {
-				return (-1);
-			}
+		    wm_lib_message(WM_MSG_LEVEL_DEBUG|WM_MSG_CLASS_MISC,"status: returned toc was NULL\n");
+		    cur_cdmode = WM_CDM_NO_DISC;
+		    return (-1);
 		}
 
 		cur_nsections = 0;
 		cur_ntracks = cd->ntracks;
 		cur_cdlen = cd->length;
-		/* load() is WorkMan database specific. Need to 
-		 * move this away.
-		 *
-		 * load(); */
 		cur_artist = cd->artist;
 		cur_cdname = cd->cdname;
 		cur_cdmode = WM_CDM_STOPPED;
@@ -470,7 +497,8 @@ cd_volume(vol, bal, max)
 	right = right < 0 ? 0 : right > 100 ? 100 : right;
 /*	printf("Left = %d, Right = %d\n", left, right);
 */
-	(void) (drive.set_volume)(&drive, left, right);
+	if(drive.set_volume != NULL)
+		(void) (drive.set_volume)(&drive, left, right);
 } /* cd_volume() */
 
 #else
@@ -509,7 +537,8 @@ cd_volume( int vol, int bal, int max )
 	if (right > 100)
 		right = 100;
 
-	(void) (drive.set_volume)(&drive, left, right);
+	if(drive.set_volume != NULL)
+		(void) (drive.set_volume)(&drive, left, right);
 } /* cd_volume() */
 
 #endif /* CLIF_VOL */
@@ -532,18 +561,20 @@ wm_cd_pause( void )
 	switch (cur_cdmode) {
 	case WM_CDM_PLAYING:		/* playing */
 		cur_cdmode = WM_CDM_PAUSED;
-		(drive.pause)(&drive);
-                paused_pos = cur_pos_rel;
+		if(drive.pause != NULL)
+			(drive.pause)(&drive);
+
+		paused_pos = cur_pos_rel;
 		break;
 
 	case WM_CDM_PAUSED:		/* paused */
 		cur_cdmode = WM_CDM_PLAYING;
 /*		(drive.resume)(&drive); */
-		if ((drive.resume)(&drive) > 0 )
-                  {
-			wm_cd_play(cur_track, paused_pos,
-				playlist[cur_listno-1].end);
-                  }
+		if(drive.resume != NULL)
+			if ((drive.resume)(&drive) > 0 )
+      	wm_cd_play(cur_track, paused_pos, playlist[cur_listno-1].end);
+		break;
+
 	default: /* */
 		break;	
 	}
@@ -564,11 +595,21 @@ wm_cd_stop( void )
 	{
 		cur_lasttrack = cur_firsttrack = -1;
 		cur_cdmode = WM_CDM_STOPPED;
-		(drive.stop)(&drive);
+		
+    if(drive.stop != NULL)
+			(drive.stop)(&drive);
+
 		cur_track = 1;
 	}
 } /* wm_cd_stop() */
- 
+
+
+void
+wm_cd_get_cdtext( void )
+{
+  wm_get_cdtext(&drive);
+}
+
 /*
  * wm_cd_play_chunk(start, end)
  *
@@ -577,6 +618,9 @@ wm_cd_stop( void )
 void
 wm_cd_play_chunk( int start, int end, int realstart )
 {
+        if(drive.get_drive_status == NULL)
+	  return;
+
 	if (cur_cdmode == WM_CDM_EJECTED || cd == NULL)
 		return;
 
@@ -584,7 +628,8 @@ wm_cd_play_chunk( int start, int end, int realstart )
 	if (start >= end)
 		start = end-1;
 
-	(drive.play)(&drive, start, end, realstart);
+	if(drive.play != NULL)
+		(drive.play)(&drive, start, end, realstart);
 }
 
 /*
@@ -596,7 +641,10 @@ wm_cd_play_chunk( int start, int end, int realstart )
 void
 wm_cd_play( int start, int pos, int end )
 {
-	if (cur_cdmode == WM_CDM_EJECTED || cd == NULL)
+        if(drive.get_drive_status == NULL)
+	  return;
+
+        if (cur_cdmode == WM_CDM_EJECTED || cd == NULL)
 		return;
 
         /*
@@ -670,6 +718,12 @@ wm_cd_eject( void )
 {
 	int	status;
 
+	if(drive.eject == NULL)
+	{
+		perror("Could not eject CD: function pointer NULL");
+		return (1);
+	}
+
 	status = (drive.eject)(&drive);
 	if (status < 0)
 	{
@@ -681,9 +735,6 @@ wm_cd_eject( void )
 		}
 	}
 	
-	if (exit_on_eject)
-		exit(0);
-
 	cur_track = -1;
 	cur_cdlen = cur_tracklen = 1;
 	cur_pos_abs = cur_pos_rel = cur_frame = 0;
@@ -694,6 +745,12 @@ wm_cd_eject( void )
 
 int wm_cd_closetray(void)
 {
+	if(drive.closetray == NULL)
+	{
+		perror("Could not close drive tray: function pointer NULL");
+		return (1);
+	}
+
 	return((drive.closetray)(&drive) ? 0 : wm_cd_status()==2 ? 1 : 0);
 } /* wm_cd_closetray() */
 
@@ -774,8 +831,9 @@ wm_cd_read_initial_volume( int max )
 {
 	int	left, right;
 
-	if ((drive.get_volume)(&drive, &left, &right) < 0 || left == -1)
-		return (max);
+	if(drive.get_volume != NULL)
+		if ((drive.get_volume)(&drive, &left, &right) < 0 || left == -1)
+			return (max);
 
 	left = (left * max + 99) / 100;
 	right = (right * max + 99) / 100;
@@ -828,5 +886,6 @@ struct wm_drive generic_proto = {
 	gen_stop,
 	gen_play,
 	gen_eject,
-	gen_closetray
+	gen_closetray,
+	gen_get_cdtext
 };
