@@ -1,5 +1,5 @@
 /*
- * $Id: plat_aix.c,v 1.5 2001/01/29 05:55:52 dfoerste Exp $
+ * $Id: plat_aix.c,v 1.6 2001/04/10 17:34:52 dfoerste Exp $
  *
  * This file is part of WorkMan, the civilized CD player library
  * (c) 1991-1997 by Steven Grimm (original author)
@@ -32,7 +32,7 @@
  */
 
 
-static char plat_aix_id[] = "$Id: plat_aix.c,v 1.5 2001/01/29 05:55:52 dfoerste Exp $";
+static char plat_aix_id[] = "$Id: plat_aix.c,v 1.6 2001/04/10 17:34:52 dfoerste Exp $";
 
 #if defined(AIXV3) || defined(__AIXV3)
 
@@ -48,6 +48,7 @@ static char plat_aix_id[] = "$Id: plat_aix.c,v 1.5 2001/01/29 05:55:52 dfoerste
 
 #include "include/wm_config.h"
 #include "include/wm_struct.h"
+#include "include/wm_cdtext.h"
 
 #define WM_MSG_CLASS WM_MSG_CLASS_PLATFORM
 
@@ -469,6 +470,16 @@ gen_get_volume(struct wm_drive *d,int *left,int *right)
   return 0;
 } /* gen_get_volume() */
 
+/*------------------------------------------------------------------------*
+ * gen_get_cdtext(drive, buffer, lenght)
+ *------------------------------------------------------------------------*/
+
+int
+gen_get_cdtext(struct wm_drive *d, unsigned char **pp_buffer, int *p_buffer_lenght)
+{
+  return -1; /* no SCSI, no CDTEXT */
+} /* gen_get_cdtext() */
+
 
 
 #endif /* _AIX */
