@@ -1,5 +1,5 @@
 /*
- * $Id: plat_svr4.c,v 1.7 2001/01/29 05:55:52 dfoerste Exp $
+ * $Id: plat_svr4.c,v 1.8 2001/04/10 17:34:52 dfoerste Exp $
  *
  * This file is part of WorkMan, the civilized CD player library
  * (c) 1991-1997 by Steven Grimm (original author)
@@ -25,7 +25,7 @@
  * SVR4 specific.  Much of this is similar to plat_hpux.c.
  */
 
-static char plat_svr4_id[] = "$Id: plat_svr4.c,v 1.7 2001/01/29 05:55:52 dfoerste Exp $";
+static char plat_svr4_id[] = "$Id: plat_svr4.c,v 1.8 2001/04/10 17:34:52 dfoerste Exp $";
 
 #if (defined(SVR4) || defined(__SVR4)) && !defined(sun) && !defined(__sun) && !defined(sony_news) && !defined(__sony_news)
 
@@ -47,6 +47,7 @@ static char plat_svr4_id[] = "$Id: plat_svr4.c,v 1.7 2001/01/29 05:55:52 dfoerst
 
 #include "include/wm_config.h"
 #include "include/wm_struct.h"
+#include "include/wm_cdtext.h"
 
 #define WM_MSG_CLASS WM_MSG_CLASS_PLATFORM
 
@@ -463,4 +464,15 @@ gen_get_volume(struct wm_drive *d, int *left, int *right)
   return (wm_scsi2_get_volume(d, left, right));
 } /* gen_get_volume() */
 
+/*------------------------------------------------------------------------*
+ * gen_get_cdtext(drive, buffer, lenght)
+ *------------------------------------------------------------------------*/
+
+int
+gen_get_cdtext(struct wm_drive *d, unsigned char **pp_buffer, int *p_buffer_lenght)
+{
+  /* This needs to be tested */
+  return wm_scsi_get_cdtext(d, pp_buffer, p_buffer_lenght);
+} /* gen_get_cdtext() */
+
 #endif
