@@ -45,7 +45,7 @@ void NukePlugin::decoder_loop() {
       break;
     case _STREAM_STATE_WAIT_FOR_END:
       // exit while loop
-      cout << "splay _STREAM_STATE_WAIT_FOR_END"<<endl;
+      cout << "nukePlugin _STREAM_STATE_WAIT_FOR_END"<<endl;
       lDecoderLoop=false;
       break;
     default:
