@@ -69,7 +69,12 @@ class VorbisPlugin : public DecoderPlugin {
   void decoder_loop();
   int seek_impl(int second);
   void config(const char* key,const char* value,void* user_data);
- 
+
+  // vorbis bug workaround [START]
+  int vorbis_seek_bug_active;
+  InputStream* getInputStream() { return input; }
+  // vorbis bug workaround [END]
+
  private:
   int processVorbis(vorbis_info* vi,vorbis_comment* comment);
   int getTotalLength();
