@@ -17,19 +17,19 @@
 
 
 
-int CDRomToc::getStartEnd(int fd,int& startToc,int& endToc) {
+int CDRomToc::getStartEnd(FILE* file,int& startToc,int& endToc) {
   cout << "CDRomToc::getStartEnd not implemented on your system"<<endl;
   return false;
 }
 
 
-int CDRomToc::readToc(int fd,int num,int& min,int& sec, int& frame) {
+int CDRomToc::readToc(FILE* file,int num,int& min,int& sec, int& frame) {
   cout << "CDRomToc::readToc not implemented on your system"<<endl;
   return false;
 }
 
 
-int CDRomToc::readLeadOut(int fd,int& min,int& sec, int& frame) {
+int CDRomToc::readLeadOut(FILE* file,int& min,int& sec, int& frame) {
   cout << "CDRomToc::reatLeadOut not implemented on your system"<<endl;
   return false;
 }
