@@ -20,7 +20,7 @@
 #define _BUFFER_HIGH_WATER  0.8
 #define _BUFFER_LOW_WATER   0.2
 
-#define _BUFFER_CHUNK_SIZE  500
+#define _BUFFER_CHUNK_SIZE  1500
 
 
 
@@ -318,7 +318,6 @@ int MpegStreamPlayer::insertVideoData(MpegSystemHeader* header,int len) {
   videoPacketCnt++;
   packetCnt++;
   timeStampVideo->setVideoFrameCounter(0);
-
   timeStampVideo->setPTSFlag(false);
   if (header->getPTSFlag()==true) {
     timeStampVideo->setPTSFlag(true);
@@ -392,7 +391,6 @@ void MpegStreamPlayer::dumpData(MpegSystemHeader* mpegSystemHeader) {
 
 int MpegStreamPlayer::finishAudio(int len) {
   int resyncState=audioDecoder->getStreamState();
-
   if (resyncState != _STREAM_STATE_RESYNC_COMMIT) {
     if (writeToDisk==true) {
       char* buf=new char[len];
@@ -404,7 +402,7 @@ int MpegStreamPlayer::finishAudio(int len) {
     }
 
   } else {
-    cout << "throw away audio"<<endl;
+    //cout << "throw away audio"<<endl;
   }
   return true;
 }
@@ -412,7 +410,6 @@ int MpegStreamPlayer::finishAudio(int len) {
 
 int MpegStreamPlayer::finishVideo(int len) {
   int resyncState=videoDecoder->getStreamState();
-
   if (resyncState != _STREAM_STATE_RESYNC_COMMIT) {
     if (writeToDisk==true) {
       char* buf=new char[len];
@@ -424,7 +421,7 @@ int MpegStreamPlayer::finishVideo(int len) {
     }
 
   } else {
-    cout <<"throw away video"<<endl;
+    //cout <<"throw away video"<<endl;
   }
   return true;
 }
