@@ -58,13 +58,15 @@ void RenderMachine::waitRestTime() {
 
 }
 
-
+int RenderMachine::x11WindowId()
+{
+	return surface->x11WindowId();
+}
 
 
 int RenderMachine::openWindow(int width, 
 			      int height,const char *title) {
-
-  if (surface->open(width,height,title)) {
+if (surface->open(width,height,title)) {
     pictureArray=new PictureArray(width, height);
     
     return switchToMode(initialMode);
