@@ -65,6 +65,11 @@ int Surface::getImageMode() {
   return 0;
 }
 
+int Surface::x11WindowId() {
+  cout << "direct virtual call  Surface::x11WindowId " << endl;
+  return -1;
+}
+
 ImageBase *Surface::findImage(int)
 {
   cout << "direct virtual call: Surface::findImage  "<<endl;
