@@ -38,10 +38,11 @@ static int dummy(Display* , XErrorEvent*) {
 #endif
 
 X11Surface::X11Surface() {
-
-  xWindow=new XWindow();
+  xWindow=(XWindow *)malloc(sizeof(XWindow));
   xWindow->lOpen=false;
   xWindow->x = xWindow->y = 0;
+  xWindow->window = 0;
+  m_windowIdAvailable = false;
   
   imageMode=_IMAGE_NONE;
 
@@ -91,6 +92,12 @@ int X11Surface::isOpen() {
   return xWindow->lOpen;
 }
 
+int X11Surface::x11WindowId() {
+  if(m_windowIdAvailable)
+  	return xWindow->window;
+  else
+    return -1;
+}
 
 int X11Surface::open(int width, int height,const char *title, bool border) {
 
@@ -146,7 +153,8 @@ int X11Surface::open(int width, int height,const char *title, bool border) {
 				InputOutput, xWindow->visual,
 				(border) ? CWBackingStore : CWBackPixel|CWOverrideRedirect,
 				&attributes);
-  
+
+  m_windowIdAvailable = true;
   if(!xWindow->window) {
     printf("\nX initialisation error:\n *** %s\n",ERR_XI_STR[ERR_XI_WINDOW]);
     printf("check ipcs and delete resources with ipcrm\n"); 
