@@ -33,10 +33,15 @@ public:
 
   DecoderPlugin* createPlugin();
 
-
+  long int x11WindowId();
+  void fullscreen(bool value);
+  bool fullscreen();
 
   void calculateBlock(unsigned long samples);
 
+private:
+  bool m_fullscreen;
+
 };
 
 
