@@ -11,8 +11,9 @@
  */
 
 
-#ifndef __DECODERBASEOBJECT_IMPL_H
-#define __DECODERBASEOBJECT_IMPL_H
+#ifndef __NULLPLAYOBJECT_IMPL_H
+#define __NULLPLAYOBJECT_IMPL_H
+
 
 
 #include <math.h>
@@ -27,7 +28,10 @@
 
 
 using namespace std;
-using namespace Arts;
+using Arts::poState;
+using Arts::poTime;
+using Arts::poCapabilities;
+
 
 class NULLPlayObject_impl :
   virtual public Arts::StdSynthModule,
